/*************************************************************************
* FILENAME: SendAnArray.c
* DATE    : September 24, 2009
* AUTHOR  : Steven A. Tretter
*
* Target-To-Host Test:
*____________________________________________________________________
* - Sends an array of 100 floats to the host via RTDX_write().
* - Uses ONE output channel.
*
* - Tests Data transmission from target to host at the User layer.
* - This is the module to be run on the TARGET(TMS320C6713DSK).
*
*   Remember to enable RTDX in CCS by clicking on Tools -> RTDX ->
*    Configuration Control and then click on the little white square
*   to the left of "Enable RTDX."
*
*    Before you enable RTDX, bring up the "RTDX Configuration Page" and select 
*   "Live Data (from target)" and "Continuous Mode."
*
*
*   The directory ...\c6713dskAnswers\RTDX_Examples\MATLAB_Plot contains a Visual
*   C++ 2008 project for building a host program for reading the numbers sent
*   by the DSK to the PC by RTDX and then calling MATLAB to plot the array
*   that was read.  The PC source program is MatlabPlot.cpp.
*
*   The interupt vectors and functions are defined in the header 
*   DSKintr.h and files intvecs.asm and DSKint.c. The object modules
*   intvecs.obj and DSKint.obj have been added to the library
*   dsk6713bsl32.lib. If you wish to modify intvecs.asm and DSKint.c, simply
*   add these source files to your project and re-compile. You can put 
*   the resulting obj's into the library using ar6x.exe.
*
*   You should use the linker command file dsk6713_RTDX.cmd
*
*   The TI RTDX tutorial shows the argument of RTDX_write( ) as a pointer
*   to an unsigned 32-bit integer array. As this example shows, it can also
*   be a float array, each word of which also occupies a 32-bit word. 
*   
*************************************************************************/
#include <stdio.h>              /* fprintf(), puts()                    */
#include <stdlib.h>             /* abort()                              */
#include <rtdx.h>               /* RTDX                                 */
#include <dsk6713.h>
#include "DSKintr.h"

/* Declare and initialize an output channel called "ochan"              */
RTDX_CreateOutputChannel(ochan);

#define ARRAY_SIZE 100

void main( void )
{
	int ind;
    float fdata[ARRAY_SIZE];   
    DSK6713_init();
    intr_reset();

    /* Turn on interrupts                                               */
    INTR_ENABLE(CPU_INT_NMI);
    INTR_ENABLE(CPU_INT_RSV2); /* RTDX uses RESV2 interrupt             */
    INTR_GLOBAL_ENABLE();
	    
    /* Enable the output channel, "ochan"                               */
    RTDX_enableOutput(&ochan);  

    /* Create data array to send to host                            */
	for(ind=0; ind < ARRAY_SIZE; ind++) fdata[ind] = (ind + 0.5)*(ind + 0.5);

    printf("\n\n Sending first array to Host.");

    /* Send the first data array to the host                          */
	if ( !RTDX_write( &ochan, fdata, sizeof(fdata) ) ) {
        fprintf(stderr, "\nError: RTDX_write() failed!\n");
        abort();
    }
        
   /* Wait for Target-to-Host transfer to complete                 */
     while ( RTDX_writing != NULL ) ;


   /* Send a second array to the host                              */
	for(ind=0; ind < ARRAY_SIZE; ind++) fdata[ind] = (100.-ind - 0.5)*(100.-ind - 0.5);
    printf("\n Sending second array to Host.\n");

    /* Send the second data array to the host                      */
	if ( !RTDX_write( &ochan, fdata, sizeof(fdata) ) ) {
        fprintf(stderr, "\nError: RTDX_write() failed!\n");
        abort();
    } 

    /* Wait for Target-to-Host transfer to complete.  This is important
       because when the channel is disabled before the data transfer is
       complete, the remaining untransmitted data is lost. In this program
       the channel is disabled immediately after the next statement. So, if
       the "while() loop was not there, the second array transfer would not
       occur.  */

	  while ( RTDX_writing != NULL );
              
    /* Display what was sent in the second array in the stdout window */
    /*  just for diagnostic purposes.                                 */

/*	for(ind = 0; ind < ARRAY_SIZE; ind++){
    fprintf(stdout, "Value %f was sent to the host\n", fdata[ind]);
    }
*/
    
    /* Disable the output channel, "ochan"                          */
    RTDX_disableOutput(&ochan);
    
    puts(" Transfer Completed.\n\n"); 
}
